@@ -10,7 +10,11 @@ use Path::Class qw( file dir );
 use Plack::Runner;
 use Plack::App::RapidApp::rDbic;
 
-use RapidApp::Include qw(sugar perlutil);
+use RapidApp::Util qw(:all);
+
+# Special case - move cuddled '-I' arg from post to last so 
+# that dbi arg logic can still work (as the second arg)
+push @ARGV, (shift @ARGV) if($ARGV[0] && $ARGV[0] =~ /^\-I\S+/);
 
 my $dsn;
 
@@ -40,6 +44,7 @@ my $tmpdir       = dir( File::Spec->tmpdir );
 my $port         = 3500;
 my $run_webapi   = 0;
 my $includes     = [];
+my $metakeys;
 
 # From 'prove': Allow cuddling the paths with -I, -M and -e
 @ARGV = map { /^(-[IMe])(.+)/ ? ($1,$2) : $_ } @ARGV;
@@ -54,7 +59,8 @@ GetOptions(
   'app-class=s'     => \$name,
   'crud-profile=s'  => \$crud_profile,
   'run-webapi+'     => \$run_webapi,
-  'I=s@'            => $includes
+  'I=s@'            => $includes,
+  'metakeys=s'      => \$metakeys
 );
 
 pod2usage(1) if ($help || !$dsn);
@@ -73,7 +79,8 @@ if (@$includes) {
     tmpdir           => $tmpdir,
     no_cleanup       => $no_cleanup,
     crud_profile     => $crud_profile,
-    isolate_app_tmp  => 1
+    isolate_app_tmp  => 1,
+    metakeys         => $metakeys
   };
   
   $cnf->{schema_class} = $schema_class if ($schema_class);
@@ -168,6 +175,7 @@ rdbic.pl - Instant CRUD webapp for your database using RapidApp/Catalyst/DBIx::C
    --no-cleanup    To leave auto-generated files on-disk after exit (in tmpdir)
    --app-class     Name to use for the generated app (defaults to 'rDbicServer')
    --run-webapi    EXPERIMENTAL: Run WebAPI::DBIC w/ HAL Browser instead of RapidApp
+   --metakeys      EXPERIMENTAL: Path to a RapidApp::Util::MetaKeys data file
 
    --crud-profile  One of five choices to broadly control CRUD interface behavior (see below)
 
@@ -239,8 +247,41 @@ this script.
 
 See L<Plack::App::RapidApp::rDbic> for more information.
 
+The C<rdbic.pl> script and L<rDbic|Plack::App::RapidApp::rDbic> Plack App were also featured in the 
+2014 Catalyst Advent Calendar:
+
+=over
+
+=item * 
+
+L<Day 16 - "Instant database admin tool with RapidApp and rdbic.pl"|http://www.catalystframework.org/calendar/2014/16>
+
+=item * 
+
+L<Day 17 - "The Plack::App::RapidApp::rDbic interface to RapidApp"|http://www.catalystframework.org/calendar/2014/17>
+
+=back
+
 =head1 SEE ALSO
 
 L<RapidApp>, L<rapidapp.pl>, L<Plack::App::RapidApp::rDbic>
 
+=head1 SUPPORT
+ 
+IRC:
+ 
+    Join #rapidapp on irc.perl.org.
+
+=head1 AUTHOR
+
+Henry Van Styn <vanstyn@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by IntelliTree Solutions llc.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+
 =cut
